from one_block.base import Base


class Accessory(Base):
    def json(self):
        pass
